import React, { useState } from 'react';
import * as d3 from 'd3';
import { dataColors } from 'config/src/colors.js';
import { DropdownButton, DropdownContainer, DropdownItemContainer } from '@graphpolaris/shared/lib/components/dropdowns';
import ColorLegend from '../colorLegend/index.js';

type TailwindColor = {
  colors: string | { [key: number]: string };
  data: { min: number; max: number };
  name: string;
  showAxis: boolean;
};

type TailwindColors = {
  [key: string]: TailwindColor;
};

function generateTailwindColors(dataColors: any) {
  const tailwindColors: TailwindColors = {};

  for (const colorName in dataColors) {
    let colorData = dataColors[colorName];

    if (colorName !== 'black' && colorName !== 'white') {
      tailwindColors[colorName] = {
        colors: colorData,
        data: { min: 0, max: 100 },
        name: `seq:${colorName}`,
        showAxis: false,
      };
    }
  }

  return tailwindColors;
}

type DropdownColorLegendProps = {
  value: any;
  onChange: (val: any) => void;
};

export const DropdownColorLegend = ({ value, onChange }: DropdownColorLegendProps) => {
  const colorStructure = generateTailwindColors(dataColors);
  const [selectedColorLegend, setSelectedColorLegend] = useState<any>(null);

  const [menuOpen, setMenuOpen] = useState<boolean>(false);
  const [selectedOption, setSelectedOption] = useState<any>('Select colormap');

  const handleButtonClick = (e: React.MouseEvent<HTMLButtonElement>) => {
    e.preventDefault();
    setMenuOpen(!menuOpen);
  };

  const handleOptionClick = (option: string) => {
    setSelectedOption(option);
    setSelectedColorLegend(colorStructure[option]);
    setMenuOpen(false);
  };

  return (
    <div className="w-200 h-200">
      <DropdownContainer className="w-60">
        <DropdownButton
          title={
            <div className="flex items-center h-4">
              {selectedColorLegend ? (
                <ColorLegend
                  colors={selectedColorLegend.colors}
                  data={selectedColorLegend.data}
                  name={selectedColorLegend.name}
                  showAxis={selectedColorLegend.showAxis}
                />
              ) : (
                <p className="ml-2">{selectedOption}</p>
              )}
            </div>
          }
          onClick={handleButtonClick}
        />
        {menuOpen && (
          <DropdownItemContainer align="top-10" className="w-60">
            {Object.keys(colorStructure).map((option: any, index) => (
              <li key={index} onClick={() => handleOptionClick(option)} className="cursor-pointer flex items-center ml-2 h-4 m-2">
                <ColorLegend
                  key={index.toString() + '_colorLegend'}
                  colors={colorStructure[option].colors}
                  data={colorStructure[option].data}
                  name={colorStructure[option].name}
                  showAxis={colorStructure[option].showAxis}
                />
              </li>
            ))}
          </DropdownItemContainer>
        )}
      </DropdownContainer>
    </div>
  );
};

export default DropdownColorLegend;
