import { Edge, Node } from '../../store';
import { CompressedElement, CompressedGraph } from './result-statistics.types';

const compressElement = (element: Node[] | Edge[]) => {
  const compressed: CompressedElement = {};

  element.forEach((item) => {
    const { label, attributes } = item;
    if (!compressed[label]) {
      compressed[label] = {};
    }
    Object.entries(attributes).forEach(([attributeId, attributeValue]) => {
      if (!compressed[label][attributeId]) {
        compressed[label][attributeId] = [];
      }
      compressed[label][attributeId].push(attributeValue);
    });
  });

  return compressed;
};

export const compressGraph = (graph: { nodes: Node[]; edges: Edge[] }): CompressedGraph => {
  try {
    return {
      nodes: compressElement(graph.nodes),
      edges: compressElement(graph.edges),
    };
  } catch (error) {
    return { nodes: {}, edges: {} };
  }
};
