import { CategoricalStats, NumericalStats, SpatialStats, TemporalStats } from './result-statistics.types';

export function extractCategoricalStats(data: any[]): CategoricalStats {
  const uniqueItems = new Set(data.map((item) => JSON.stringify(item)));
  return {
    uniqueItems: uniqueItems.size,
  };
}

export function extractNumericalStats(data: number[]): NumericalStats {
  const minValue = Math.min(...data);
  const maxValue = Math.max(...data);
  const sum = data.reduce((acc, curr) => acc + curr, 0);
  const avgValue = sum / data.length;
  return {
    minValue,
    maxValue,
    avgValue,
  };
}

export function extractTemporalStats(data: Date[]): TemporalStats {
  const sortedDates = data.slice().sort((a, b) => a.getTime() - b.getTime());
  const minDate = sortedDates[0];
  const maxDate = sortedDates[sortedDates.length - 1];
  return {
    minDate,
    maxDate,
  };
}

export function extractSpatialStats(data: [number, number][]): SpatialStats {
  const totalPoints = data.length;
  const sumCoordinates = data.reduce(([x1, y1], [x2, y2]) => [x1 + x2, y1 + y2], [0, 0]);
  const middlePoint: [number, number] = [sumCoordinates[0] / totalPoints, sumCoordinates[1] / totalPoints];
  return {
    middlePoint,
  };
}
