import { extractCategoricalStats, extractNumericalStats, extractSpatialStats, extractTemporalStats } from './dimensions';
import { CompressedElement, DimensionInfoType, DimensionStatistics, ElementStatisticsType } from './result-statistics.types';

export const extractStatistics = (elements: CompressedElement, dimensions: DimensionInfoType) => {
  const statistics: ElementStatisticsType = {};

  Object.keys(elements).forEach((label) => {
    statistics[label] = {};
    Object.entries(elements[label]).forEach(([attributeId, attributeValues]) => {
      const dimensionType = dimensions[label][attributeId];
      statistics[label][attributeId] = { dimension: dimensionType };
      statistics[label][attributeId].stats = calculateStatistics(attributeValues, dimensionType, statistics[label][attributeId].stats);
    });
  });

  return statistics;
};

export const calculateStatistics = (item: any[], dimensionType: string, statsField: any) => {
  let stats: DimensionStatistics | undefined;
  switch (dimensionType) {
    case 'categorical':
      stats = extractCategoricalStats(item);
      break;
    case 'numerical':
      stats = extractNumericalStats(item);
      break;
    case 'spatial':
      stats = extractSpatialStats(item);
      break;
    case 'temporal':
      stats = extractTemporalStats(item);
      break;
    default:
      break;
  }

  if (stats !== undefined) {
    statsField = statsField || {};
    for (const key in stats) {
      if (Object.prototype.hasOwnProperty.call(stats, key)) {
        const statsKey = key as keyof DimensionStatistics;
        if (typeof stats[statsKey] === 'number') {
          statsField[statsKey] = (statsField[statsKey] || 0) + stats[statsKey];
        } else if (Array.isArray(stats[statsKey])) {
          statsField[statsKey] = (statsField[statsKey] || []).concat(stats[statsKey] as any[]);
        } else {
          throw new Error('Invalid stats type');
        }
      }
    }
  }

  return statsField || {};
};
