import { Node, Edge } from '../../store/graphQueryResultSlice';
import { QueryMultiGraph } from '../../../querybuilder';
import { GraphStatistics, DimensionMap, CompressedGraph } from './result-statistics.types';
import { compressGraph } from './compress-graph';
import { extractStatistics } from './extract-stats';
import { extractAttributeDimensions } from './extract-dimensions';

export const retrieveGraphStatistics = (graph: { nodes: Node[]; edges: Edge[] }, qbGraph: QueryMultiGraph): GraphStatistics => {
  try {
    const compressedGraph: CompressedGraph = compressGraph(graph);

    const nodeAttributes = extractAttributeDimensions(qbGraph, 'entity');
    const edgeAttributes = extractAttributeDimensions(qbGraph, 'relation');
    const dimensionMap: DimensionMap = { nodes: nodeAttributes, edges: edgeAttributes };

    return {
      nodes: extractStatistics(compressedGraph.nodes, dimensionMap.nodes),
      edges: extractStatistics(compressedGraph.edges, dimensionMap.edges),
    };
  } catch (error) {
    return {
      nodes: {},
      edges: {},
    };
  }
};
