import React, { useState, useEffect } from 'react';
import Input from '@graphpolaris/shared/lib/components/inputs';
import { useQuerybuilderGraph } from '@graphpolaris/shared/lib/data-access';

type Props = {
  value: string | undefined;
  onChange: (val: string | number) => void;
  element: 'node' | 'edge';
  dimension?: string[];
  disabled?: boolean;
};

export default function Accessor({ value, onChange, element, dimension, disabled = false }: Props) {
  const qbGraph = useQuerybuilderGraph();
  const [options, setOptions] = useState<string[]>([]);

  useEffect(() => {
    let commonAttributes: Set<string> = new Set();

    if (element === 'node') {
      qbGraph.nodes
        .filter((node) => node.attributes?.type === 'entity')
        .forEach((node) => {
          const nodeAttributes = new Set<string>();
          node.attributes?.attributes?.forEach((attr) => {
            if (attr.handleData?.attributeDimension && dimension?.includes(attr.handleData?.attributeDimension)) {
              attr.handleData.attributeName && nodeAttributes.add(`attributes.${attr.handleData.attributeName}`);
            }
          });
          if (commonAttributes.size === 0) {
            commonAttributes = nodeAttributes;
          } else {
            commonAttributes = new Set([...commonAttributes].filter((x) => nodeAttributes.has(x)));
          }
        });
    } else {
      qbGraph.nodes
        .filter((edge) => edge.attributes?.type === 'relation')
        .forEach((edge) => {
          const edgeAttributes = new Set<string>();
          edge.attributes?.attributes?.forEach((attr) => {
            if (attr.handleData?.attributeDimension && dimension?.includes(attr.handleData?.attributeDimension)) {
              attr.handleData.attributeName && edgeAttributes.add(`attributes.${attr.handleData.attributeName}`);
            }
          });
          if (commonAttributes.size === 0) {
            commonAttributes = edgeAttributes;
          } else {
            commonAttributes = new Set([...commonAttributes].filter((x) => edgeAttributes.has(x)));
          }
        });
    }

    setOptions(Array.from(commonAttributes));
  }, [element, dimension]);

  return (
    <div className="mb-2">
      <Input type="dropdown" value={value} onChange={(val: string | number) => onChange(val)} options={options} disabled={disabled} />
    </div>
  );
}
