import React, { useState, useEffect } from 'react';
import { useAppDispatch, useVisEncodings } from '@graphpolaris/shared/lib/data-access';
import { updateVisEncodings } from '@graphpolaris/shared/lib/data-access/store/visualizationSlice';
import Accessor from './accessor';
import Info from '@graphpolaris/shared/lib/components/info';
import { isEqual } from 'lodash-es';
import Selector from './selector';
import { EncodingTypes } from './encodings.types';

export default function EncodingPanel() {
  const dispatch = useAppDispatch();
  const encodings = useVisEncodings();
  const [encodingUpdates, setEncodingUpdates] = useState<{
    [id: string]: {
      marking: any;
      accessorPath: string;
    };
  }>({});

  useEffect(() => {
    const newEncodings: EncodingTypes = Object.fromEntries(
      Object.entries(encodings).map(([key, immutableEncoding]) => [
        key,
        {
          ...(immutableEncoding || {}),
          ...(encodingUpdates[key] || {}),
        },
      ])
    );

    if (!isEqual(encodings, newEncodings)) {
      dispatch(updateVisEncodings(newEncodings));
    }
  }, [encodingUpdates, encodings, dispatch]);

  const updateEncoding = (encoding: string, val: any, type: 'accessorPath' | 'marking') => {
    setEncodingUpdates((prevState) => {
      if (prevState) {
        return {
          ...prevState,
          [encoding]: {
            ...(prevState[encoding] || {}),
            [type]: val,
          },
        };
      } else {
        return prevState;
      }
    });
  };

  return (
    encodings && (
      <div>
        {Object.keys(encodings).map((k) => {
          const item = encodings[k];
          const value = encodingUpdates[k] ? encodingUpdates[k] : { marking: undefined, accessorPath: undefined };

          return (
            <div key={k} className="bg-secondary-50 p-2 m-1">
              <div className="flex items-center justify-between">
                <h1 className="text-xs">{item.label ? item.label : k}</h1>
                {item.description && <Info tooltip={item.description} />}
              </div>
              <Accessor
                value={value.accessorPath}
                onChange={(value: string | number) => updateEncoding(k, value, 'accessorPath')}
                element={item.element}
                dimension={item.dimension ?? []}
              />
              {value.accessorPath && (
                <Selector
                  key={k}
                  selectorType={item.selector}
                  marking={value.marking}
                  onChange={(value: any) => updateEncoding(k, value, 'marking')}
                  accessorPath={value.accessorPath}
                />
              )}
            </div>
          );
        })}
      </div>
    )
  );
}
