import React from 'react';
import { FormTitle } from '@graphpolaris/shared/lib/components/forms';
import { AutoAwesome, CandlestickChart, LockOpen, Settings } from '@mui/icons-material';
import { useVisualizationState } from '@graphpolaris/shared/lib/data-access';
import TabItem from './tab-item';

type Props = {
  onClose: any;
  activeTab: number;
  setActiveTab: any;
};

export default function PanelHeader({ onClose, activeTab, setActiveTab }: Props) {
  const vis = useVisualizationState();

  const encodings = vis.settings[vis.activeVisualization]?.encodings;
  const encodingsExist = encodings && Object.keys(encodings).length > 0;
  const settings = vis.settings[vis.activeVisualization]?.settings;
  const settingsExist = settings && Object.keys(settings).length > 0;
  const interactions = vis.settings[vis.activeVisualization]?.interactions;
  const interactionsExist = interactions && Object.keys(interactions).length > 0;

  return (
    <div className="flex flex-col pt-2 bg-secondary-100">
      <FormTitle title="Settings" onClose={onClose} />
      <ul className="flex flex-wrap pt-4 pl-5 text-sm font-medium text-center text-gray-500 dark:text-gray-400">
        {encodingsExist && <TabItem active={activeTab === 0} onClick={() => setActiveTab(0)} icon={<AutoAwesome />} tooltip="Encodings" />}
        {settingsExist && <TabItem active={activeTab === 1} onClick={() => setActiveTab(1)} icon={<Settings />} tooltip="Settings" />}
        {interactionsExist && (
          <TabItem active={activeTab === 2} onClick={() => setActiveTab(2)} icon={<CandlestickChart />} tooltip="Interactions" />
        )}
        {(settingsExist || encodingsExist || interactionsExist) && (
          <TabItem active={activeTab === 3} onClick={() => setActiveTab(3)} icon={<LockOpen />} tooltip="Advanced" />
        )}
      </ul>
    </div>
  );
}
