import React, { useState, useEffect } from 'react';
import { useAppDispatch, useGeneralSettings, useVisSettings, useVisualizationState } from '@graphpolaris/shared/lib/data-access';
import { globalConfigTypes } from '../../types';
import { FormControl } from '@graphpolaris/shared/lib/components/forms';
import Input from '@graphpolaris/shared/lib/components/inputs';
import { updateGeneralSettings, updateVisSettings } from '@graphpolaris/shared/lib/data-access/store/visualizationSlice';

export default function SettingsPanel() {
  const dispatch = useAppDispatch();
  const vis = useVisualizationState();

  const generalSettings = useGeneralSettings();
  const [settingsGeneral, setSettingsGeneral] = useState<globalConfigTypes>(generalSettings);

  const visSettings = useVisSettings();
  const [settingsSpecific, setSettingsSpecific] = useState(visSettings);

  useEffect(() => {
    if (settingsGeneral !== generalSettings) {
      dispatch(updateGeneralSettings(settingsGeneral));
    }
  }, [settingsGeneral]);

  useEffect(() => {
    if (settingsSpecific !== visSettings) {
      dispatch(updateVisSettings(settingsSpecific));
    }
  }, [settingsSpecific]);

  useEffect(() => {
    if (visSettings !== settingsSpecific) {
      setSettingsSpecific(visSettings);
    }
  }, [vis.activeVisualization]);

  return (
    generalSettings &&
    visSettings && (
      <div>
        <div>
          {Object.keys(settingsGeneral).map((val) => (
            <FormControl key={val}>
              <Input
                {...settingsGeneral[val]}
                value={vis.settings.general[val].value as any}
                onChange={(value: any) => {
                  setSettingsGeneral((prevSettings) => ({
                    ...prevSettings,
                    [val]: { ...prevSettings[val], value: value },
                  }));
                }}
              />
            </FormControl>
          ))}
        </div>

        <div>
          {Object.keys(settingsSpecific).map((val) => {
            const currentSetting = settingsSpecific[val];
            const shouldShowSetting = currentSetting.condition ? currentSetting.condition?.(settingsSpecific.settings) : true;
            return (
              shouldShowSetting && (
                <div key={val} className="bg-secondary-50 p-2 m-2">
                  <FormControl>
                    <Input
                      {...settingsSpecific[val]}
                      value={settingsSpecific[val]?.value as any}
                      onChange={(value: any) => {
                        setSettingsSpecific((prevSettings) => ({
                          ...prevSettings,
                          [val]: { ...prevSettings[val], value: value },
                        }));
                      }}
                    />
                  </FormControl>
                </div>
              )
            );
          })}
        </div>
      </div>
    )
  );
}
