import * as d3 from 'd3';
import GeoNode from './node';
import GeoEdge from './edge';
import { calcAverageCoordinates } from '../utils';

export const facetNodes = (nodes: GeoNode[], dimension: string) => {
  const nodesByAttribute: Map<string, GeoNode[]> = d3.group(nodes, (node: GeoNode) => eval(`node.data.${dimension}`));

  const bundleByAttribute: GeoNode[] = [];

  nodesByAttribute.forEach((group) => {
    const lat: number[] = [];
    const long: number[] = [];
    const locations: any[] = [];

    group.forEach((node: GeoNode) => {
      const coordinates: number[] = node.getCoordinates();
      lat.push(coordinates[0]);
      long.push(coordinates[1]);
      locations.push(node.id);
    });

    const average: [number, number] = calcAverageCoordinates(lat, long);
    const name: string = eval(`group[0].data.${dimension}`);

    bundleByAttribute.push(
      new GeoNode({
        id: name,
        lon: average[0],
        lat: average[1],
        data: {
          locations: locations,
        },
      })
    );
  });

  return bundleByAttribute;
};

export const updateEdges = (nodes: GeoNode[], edges: GeoEdge[]) => {
  const locations: { [key: string]: string[] } = nodes.reduce((locations: { [key: string]: string[] }, node: GeoNode) => {
    locations[node.id] = node.data.locations;
    return locations;
  }, {});

  const bundles: { [key: string]: GeoEdge } = {};

  edges.forEach((edge: GeoEdge) => {
    const from_location: string | undefined = Object.keys(locations).find((state) => locations[state].includes(edge.from as string));

    const to_location: string | undefined = Object.keys(locations).find((state) => locations[state].includes(edge.to as string));

    if (from_location && to_location) {
      if (from_location === to_location) return; // edge is within group

      const from: number[] | undefined = nodes.find((node: GeoNode) => node.id === from_location)?.getCoordinates();
      const to: number[] | undefined = nodes.find((node: GeoNode) => node.id === to_location)?.getCoordinates();

      const key = `${from_location}-${to_location}`;
      if (!(key in bundles)) {
        edge.source = from ? [from[0], from[1]] : null;
        edge.target = to ? [to[0], to[1]] : null;
        bundles[key] = edge;
      } else {
        bundles[key].count += 1;
      }
    }
  });

  return Object.values(bundles);
};
