import React, { useEffect, useRef, useState } from 'react';
import { useImmer } from 'use-immer';
import { GraphQueryResult } from '../../../data-access/store';
import { LinkType, NodeType } from './Types';
import { MatrixPixi } from './components/MatrixPixi';
import { VisualizationPropTypes, VISComponentType } from '../../types';

export const MatrixVis = React.memo(({ data, ml, settings }: VisualizationPropTypes) => {
  const ref = useRef<HTMLDivElement>(null);
  const [graph, setGraph] = useImmer<GraphQueryResult | undefined>(undefined);
  const [highlightNodes, setHighlightNodes] = useState<NodeType[]>([]);
  const [highlightedLinks, setHighlightedLinks] = useState<LinkType[]>([]);

  useEffect(() => {
    if (data) {
      setGraph(data);
    }
  }, [data, ml]);

  return (
    <>
      <div className="h-full w-full overflow-hidden" ref={ref}>
        <MatrixPixi graph={graph} highlightNodes={highlightNodes} highlightedLinks={highlightedLinks} localConfig={settings} />
      </div>
    </>
  );
});

const displayName = 'MatrixVis';

export const MatrixVisComponent: VISComponentType = {
  displayName: displayName,
  VIS: MatrixVis,
  settings: {
    marks: {
      type: 'dropdown',
      options: ['rect', 'circle'],
      value: 'rect',
      label: 'Configure Marks',
    },
  },
};

export default MatrixVisComponent;
